package com.yijia.station.mapper;

import java.util.List;
import com.yijia.station.domain.StationInfo;

/**
 * 油站信息Mapper接口
 * 
 * @author yijia
 * @date 2020-12-08
 */
public interface StationInfoMapper 
{
    /**
     * 查询油站信息
     * 
     * @param stationId 油站信息ID
     * @return 油站信息
     */
    public StationInfo selectStationInfoById(Long stationId);

    /**
     * 查询油站信息列表
     * 
     * @param stationInfo 油站信息
     * @return 油站信息集合
     */
    public List<StationInfo> selectStationInfoList(StationInfo stationInfo);

    /**
     * 新增油站信息
     * 
     * @param stationInfo 油站信息
     * @return 结果
     */
    public int insertStationInfo(StationInfo stationInfo);

    /**
     * 修改油站信息
     * 
     * @param stationInfo 油站信息
     * @return 结果
     */
    public int updateStationInfo(StationInfo stationInfo);

    /**
     * 删除油站信息
     * 
     * @param stationId 油站信息ID
     * @return 结果
     */
    public int deleteStationInfoById(Long stationId);

    /**
     * 批量删除油站信息
     * 
     * @param stationIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteStationInfoByIds(Long[] stationIds);
}
